
.. .. image:: https://readthedocs.org/projects/aws-glue-catalog/badge/?version=latest
    :target: https://aws-glue-catalog.readthedocs.io/en/latest/
    :alt: Documentation Status

.. .. image:: https://github.com/MacHu-GWU/aws_glue_catalog-project/actions/workflows/main.yml/badge.svg
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/aws_glue_catalog-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_glue_catalog-project

.. image:: https://img.shields.io/pypi/v/aws-glue-catalog.svg
    :target: https://pypi.python.org/pypi/aws-glue-catalog

.. image:: https://img.shields.io/pypi/l/aws-glue-catalog.svg
    :target: https://pypi.python.org/pypi/aws-glue-catalog

.. image:: https://img.shields.io/pypi/pyversions/aws-glue-catalog.svg
    :target: https://pypi.python.org/pypi/aws-glue-catalog

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project

------

.. .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws-glue-catalog.readthedocs.io/en/latest/

.. .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws-glue-catalog.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_glue_catalog-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws-glue-catalog#files


Welcome to ``aws_glue_catalog`` Documentation
==============================================================================
.. .. image:: https://aws-glue-catalog.readthedocs.io/en/latest/_static/aws_glue_catalog-logo.png
    :target: https://aws-glue-catalog.readthedocs.io/en/latest/

AWS Glue Catalog tools.


.. _install:

Install
------------------------------------------------------------------------------

``aws_glue_catalog`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install aws-glue-catalog

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws-glue-catalog
